@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Rajko Albrecht                                  *
+ *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -62,6 +62,18 @@ static const char description[] =
 kdesvnPart::kdesvnPart( QWidget *parentWidget, const char *widgetName,
                                   QObject *parent, const char *name , const QStringList&)
     : KParts::ReadOnlyPart(parent, name)
+{
+    init(parentWidget,widgetName,false);
+}
+
+kdesvnPart::kdesvnPart(QWidget *parentWidget, const char *widgetName,
+               QObject *parent, const char *name,bool ownapp, const QStringList&)
+    : KParts::ReadOnlyPart(parent, name)
+{
+    init(parentWidget,widgetName,ownapp);
+}
+
+void kdesvnPart::init( QWidget *parentWidget, const char *widgetName,bool full)
 {
     m_aboutDlg = 0;
     KGlobal::locale()->insertCatalogue("kdesvn");
@@ -70,7 +82,7 @@ kdesvnPart::kdesvnPart( QWidget *parentWidget, const char *widgetName,
     m_browserExt = new KdesvnBrowserExtension( this );
 
     // this should be your custom internal widget
-    m_view = new kdesvnView(actionCollection(),parentWidget,widgetName);
+    m_view = new kdesvnView(actionCollection(),parentWidget,widgetName,full);
 
     // notify the part that this is our internal widget
     setWidget(m_view);
@@ -146,11 +158,11 @@ KAboutData* kdesvnPart::createAboutData()
     m_Extratext+=QString(I18N_NOOP("Running Subversion library: %1")).arg(svn::Version::running_version());
 
     KAboutData*about = new KAboutData("kdesvnpart", I18N_NOOP("kdesvn Part"), version, description,
-                     KAboutData::License_GPL, "(C) 2005 Rajko Albrecht",0,
+                     KAboutData::License_GPL, "(C) 2005-2007 Rajko Albrecht",0,
                          0, "ral@alwins-world.de");
     about->addAuthor( "Rajko Albrecht", 0, "ral@alwins-world.de" );
     about->setOtherText(m_Extratext);
-    about->setHomepage("http://www.alwins-world.de/programs/kdesvn/");
+    about->setHomepage("http://kdesvn.alwins-world.de/");
     about->setBugAddress("kdesvn-bugs@alwins-world.de");
     about->setTranslator(I18N_NOOP("kdesvn: NAME OF TRANSLATORS\\nYour names"),
         I18N_NOOP("kdesvn: EMAIL OF TRANSLATORS\\nYour emails"));
@@ -164,10 +176,6 @@ KAboutData* kdesvnPart::createAboutData()
 void kdesvnPart::setupActions()
 {
     KToggleAction *toggletemp;
-    toggletemp = new KToggleAction(i18n("Use \"Kompare\" for displaying diffs"),KShortcut(),
-            actionCollection(),"toggle_use_kompare");
-    toggletemp->setChecked(Kdesvnsettings::use_kompare_for_diff());
-    connect(toggletemp,SIGNAL(toggled(bool)),this,SLOT(slotUseKompare(bool)));
 
     toggletemp = new KToggleAction(i18n("Logs follow node changes"),KShortcut(),
             actionCollection(),"toggle_log_follows");
@@ -179,13 +187,16 @@ void kdesvnPart::setupActions()
     toggletemp->setChecked(Kdesvnsettings::display_ignored_files());
     connect(toggletemp,SIGNAL(toggled(bool)),this,SLOT(slotDisplayIgnored(bool)));
 
-#if 0
-    /// not needed this moment
+
     toggletemp = new KToggleAction(i18n("Display unknown files"),KShortcut(),
             actionCollection(),"toggle_unknown_files");
-    toggletemp->setChecked(kdesvnPart_Prefs::self()->mdisp_unknown_files);
+    toggletemp->setChecked(Kdesvnsettings::display_unknown_files());
     connect(toggletemp,SIGNAL(toggled(bool)),this,SLOT(slotDisplayUnkown(bool)));
-#endif
+
+    toggletemp = new KToggleAction(i18n("Hide unchanged files"),KShortcut(),
+                                   actionCollection(),"toggle_hide_unchanged_files");
+    toggletemp->setChecked(Kdesvnsettings::hide_unchanged_files());
+    connect(toggletemp,SIGNAL(toggled(bool)),this,SLOT(slotHideUnchanged(bool)));
 
     kdDebug()<<"Appname = " << (QString)kapp->instanceName() << endl;
 
@@ -229,26 +240,23 @@ void kdesvnPart::slotDisplayIgnored(bool how)
 /*!
     \fn kdesvnPart::slotDisplayUnknown(bool)
  */
-void kdesvnPart::slotDisplayUnkown(bool )
+void kdesvnPart::slotDisplayUnkown(bool how)
 {
-#if 0
-    kdesvnPart_Prefs::self()->mdisp_unknown_files=how;
-    kdesvnPart_Prefs::self()->writeConfig();
-#endif
+    Kdesvnsettings::setDisplay_unknown_files(how);
+    Kdesvnsettings::writeConfig();
+    emit refreshTree();
 }
 
-
 /*!
-    \fn kdesvnPart::slotUseKompare(bool)
+    \fn kdesvnPart::slotHideUnchanged(bool)
  */
-void kdesvnPart::slotUseKompare(bool how)
+void kdesvnPart::slotHideUnchanged(bool how)
 {
-    int selected = how ? 1 : 0;
-    Kdesvnsettings::setUse_kompare_for_diff(selected);
+    Kdesvnsettings::setHide_unchanged_files(how);
     Kdesvnsettings::writeConfig();
+    emit refreshTree();
 }
 
-
 /*!
     \fn kdesvnPart::closeURL()
  */
@@ -356,10 +364,6 @@ void kdesvnPart::slotShowSettings()
 void kdesvnPart::slotSettingsChanged()
 {
     KAction * temp;
-    temp = actionCollection()->action("toggle_use_kompare");
-    if (temp) {
-        ((KToggleAction*)temp)->setChecked(Kdesvnsettings::use_kompare_for_diff()==1);
-    }
     temp = actionCollection()->action("toggle_log_follows");
     if (temp) {
         ((KToggleAction*)temp)->setChecked(Kdesvnsettings::log_follows_nodes());
@@ -390,7 +394,17 @@ KParts::Part* cFactory::createPartObject( QWidget *parentWidget, const char *wid
 {
     Q_UNUSED(classname);
     // Create an instance of our Part
-    kdesvnPart* obj = new kdesvnPart( parentWidget, widgetName, parent, name, args );
+    return new kdesvnPart( parentWidget, widgetName, parent, name, args );
+}
+
+KParts::Part* cFactory::createAppPart( QWidget *parentWidget, const char *widgetName,
+                                          QObject *parent, const char *name,
+                                          const char *classname, const QStringList &args )
+{
+    Q_UNUSED(classname);
+    // Create an instance of our Part
+    kdesvnPart* obj = new kdesvnPart( parentWidget, widgetName, parent, name, false, args);
+    emit objectCreated( obj );
     return obj;
 }
 
@@ -416,6 +430,7 @@ KInstance* cFactory::instance()
 commandline_part*cFactory::createCommandIf(QObject*parent,const char*name, KCmdLineArgs *args)
 {
     if (!s_cline) {
+        // no emit of creation - we will delete this object in destructor
         s_cline = new commandline_part(parent,name,args);
     }
     return s_cline;
