@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Rajko Albrecht                                  *
+ *   Copyright (C) 2006-2007 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -376,6 +376,7 @@ QColor RevGraphView::getBgColor(const QString&nodeName)const
         case 'D':
             res = Kdesvnsettings::tree_delete_color();
             break;
+        case 'R':
         case 'M':
             res = Kdesvnsettings::tree_modify_color();
             break;
@@ -386,7 +387,6 @@ QColor RevGraphView::getBgColor(const QString&nodeName)const
         case 1:
             res = Kdesvnsettings::tree_copy_color();
             break;
-        case 'R':
         case 2:
             res = Kdesvnsettings::tree_rename_color();
             break;
@@ -429,6 +429,9 @@ const QString&RevGraphView::getLabelstring(const QString&nodeName)
     case 'M':
         res = i18n("Modified at revision %1").arg(it1.data().rev);
     break;
+    case 'R':
+        res = i18n("Replaced at revision %1").arg(it1.data().rev);
+        break;
     default:
         res=i18n("Revision %1").arg(it1.data().rev);
     break;
@@ -540,7 +543,7 @@ QString RevGraphView::toolTip(const QString&_nodename,bool full)const
 
     if (!full) {
         res+=QString("<b>%1</b>").arg(it.data().name);
-        res += i18n("<br>Revision: %1<br>Author: %2<br>Date: %3<br>Log:%4</html>")
+        res += i18n("<br>Revision: %1<br>Author: %2<br>Date: %3<br>Log: %4</html>")
             .arg(it.data().rev)
             .arg(it.data().Author)
             .arg(it.data().Date)
