@@ -17,6 +17,9 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
+
+#include "src/svnfrontend/fronthelpers/propertyitem.h"
+#include "src/svnfrontend/fronthelpers/propertylist.h"
 #include "propertiesdlg.h"
 #include "editproperty_impl.h"
 #include "svnitem.h"
@@ -25,7 +28,6 @@
 #include <qvariant.h>
 #include <qlabel.h>
 #include <qheader.h>
-#include <klistview.h>
 #include <kpushbutton.h>
 #include <qlayout.h>
 #include <qtooltip.h>
@@ -35,77 +37,6 @@
 #include <kiconloader.h>
 #include <kdebug.h>
 
-class PropertyListViewItem:public KListViewItem
-{
-    friend class PropertiesDlg;
-public:
-    PropertyListViewItem(KListView *parent,const QString&,const QString&);
-    PropertyListViewItem(KListView *parent);
-    virtual ~PropertyListViewItem();
-
-    const QString&startName()const{return m_startName;}
-    const QString&startValue()const{return m_startValue;}
-    const QString&currentName()const{return m_currentName;}
-    const QString&currentValue()const{return m_currentValue;}
-
-    void checkValue();
-    void checkName();
-    void deleteIt();
-    void unDeleteIt();
-    bool deleted()const{return m_deleted;}
-
-    bool different()const;
-
-protected:
-    QString m_currentName,m_startName,m_currentValue,m_startValue;
-    bool m_deleted;
-};
-
-PropertyListViewItem::PropertyListViewItem(KListView *parent,const QString&aName,const QString&aValue)
-    : KListViewItem(parent),m_currentName(aName),m_startName(aName),m_currentValue(aValue),m_startValue(aValue),m_deleted(false)
-{
-    setText(0,startName());
-    setText(1,startValue());
-}
-
-PropertyListViewItem::PropertyListViewItem(KListView *parent)
-    : KListViewItem(parent),m_currentName(""),m_startName(""),m_currentValue(""),m_startValue(""),m_deleted(false)
-{
-    setText(0,startName());
-    setText(1,startValue());
-}
-
-PropertyListViewItem::~PropertyListViewItem()
-{
-}
-
-void PropertyListViewItem::checkValue()
-{
-    m_currentValue=text(1);
-}
-
-void PropertyListViewItem::checkName()
-{
-    m_currentName=text(0);
-}
-
-bool PropertyListViewItem::different()const
-{
-    return m_currentName!=m_startName || m_currentValue!=m_startValue || deleted();
-}
-
-void PropertyListViewItem::deleteIt()
-{
-    m_deleted = true;
-    setPixmap(0,KGlobal::iconLoader()->loadIcon("cancel",KIcon::Desktop,16));
-}
-
-void PropertyListViewItem::unDeleteIt()
-{
-    m_deleted = false;
-    setPixmap(0,QPixmap());
-}
-
 /*
  *  Constructs a PropertiesDlg as a child of 'parent', with the
  *  name 'name' and widget flags set to 'f'.
@@ -125,17 +56,14 @@ PropertiesDlg::PropertiesDlg(SvnItem*which, svn::Client*aClient, const svn::Revi
     QWidget * m = makeMainWidget();
     PropertiesDlgLayout = new QHBoxLayout(m, marginHint(), spacingHint(), "PropertiesDlgLayout");
 
-    m_PropertiesListview = new KListView(m, "m_PropertiesListview" );
-    m_PropertiesListview->addColumn( i18n( "Properties" ) );
-    m_PropertiesListview->addColumn( i18n( "Value" ) );
+    m_PropertiesListview = new Propertylist(m, "m_PropertiesListview" );
     m_PropertiesListview->setAllColumnsShowFocus( TRUE );
     m_PropertiesListview->setShowSortIndicator( TRUE );
-    //m_PropertiesListview->setDefaultRenameAction( KListView::Accept );
-#if 0
+    m_PropertiesListview->setCommitchanges(false);
     m_PropertiesListview->setItemsRenameable(true);
     m_PropertiesListview->setRenameable(0,true);
     m_PropertiesListview->setRenameable(1,true);
-#endif
+
     m_PropertiesListview->setFullWidth( TRUE );
     PropertiesDlgLayout->addWidget( m_PropertiesListview);
 
@@ -161,7 +89,6 @@ PropertiesDlg::PropertiesDlg(SvnItem*which, svn::Client*aClient, const svn::Revi
     connect( m_ModifyButton, SIGNAL(clicked()), this, SLOT(slotModify()));
     connect( m_DeleteButton, SIGNAL(clicked()), this, SLOT(slotDelete()));
     connect(this,SIGNAL(helpClicked()),SLOT(slotHelp()));
-    connect(m_PropertiesListview,SIGNAL(itemRenamed(QListViewItem*,const QString&,int)),this,SLOT(slotItemRenamed(QListViewItem*,const QString&,int)));
     connect(m_PropertiesListview,SIGNAL(selectionChanged(QListViewItem*)),this,SLOT(slotSelectionChanged(QListViewItem*)));
 //    connect(m_PropertiesListview,SIGNAL(executed(QListViewItem*)),this,SLOT(slotSelectionExecuted(QListViewItem*)));
 
@@ -190,8 +117,6 @@ PropertiesDlg::~PropertiesDlg()
 void PropertiesDlg::languageChange()
 {
     setCaption( i18n("View and modify properties") );
-    m_PropertiesListview->header()->setLabel( 0, i18n( "Properties" ) );
-    m_PropertiesListview->header()->setLabel( 1, i18n( "Value" ) );
     QToolTip::add(m_PropertiesListview, i18n( "List of properties set" ));
     m_AddButton->setText(i18n("Add property"));
     m_ModifyButton->setText(i18n("Modify property"));
@@ -207,9 +132,9 @@ void PropertiesDlg::slotSelectionChanged(QListViewItem*item)
 {
     m_DeleteButton->setEnabled(item);
     m_ModifyButton->setEnabled(item);
-    if (!item) return;
+    if (!item || item->rtti()!=PropertyListViewItem::_RTTI_) return;
     PropertyListViewItem*ki = static_cast<PropertyListViewItem*> (item);
-    if (protected_Property(ki->currentName())) {
+    if (PropertyListViewItem::protected_Property(ki->currentName())) {
         m_DeleteButton->setEnabled(false);
         m_ModifyButton->setEnabled(false);
         return;
@@ -235,27 +160,14 @@ void PropertiesDlg::initItem()
         return;
     }
     svn::Path what(m_Item->fullName());
-    svn::PathPropertiesMapList propList;
+    svn::PathPropertiesMapListPtr propList;
     try {
         propList = m_Client->proplist(what,m_Rev,m_Rev);
     } catch (svn::ClientException e) {
         emit clientException(e.msg());
         return;
     }
-    svn::PathPropertiesMapList::const_iterator lit;
-    svn::PropertiesMap pmap;
-    for (lit=propList.begin();lit!=propList.end();++lit) {
-        pmap = (*lit).second;
-        /* just want the first one */
-        break;
-    }
-    svn::PropertiesMap::const_iterator pit;
-    for (pit=pmap.begin();pit!=pmap.end();++pit) {
-        PropertyListViewItem * ki = new PropertyListViewItem(m_PropertiesListview,
-            pit.key(),
-            pit.data());
-        ki->setMultiLinesEnabled(true);
-    }
+    m_PropertiesListview->displayList(propList,true,m_Item->fullName());
     initDone = true;
 }
 
@@ -264,7 +176,6 @@ void PropertiesDlg::initItem()
  */
 int PropertiesDlg::exec()
 {
-    kdDebug()<<"Exec"<<endl;
     return KDialogBase::exec();
 }
 
@@ -281,21 +192,6 @@ void PropertiesDlg::slotSelectionExecuted(QListViewItem*)
 {
 }
 
-/*!
-    \fn PropertiesDlg::slotItemRenamed(QListViewItem*item,const QString & str,int col )
- */
-void PropertiesDlg::slotItemRenamed(QListViewItem*_item,const QString &,int col )
-{
-    if (!_item) return;
-    PropertyListViewItem*item = static_cast<PropertyListViewItem*> (_item);
-    if (col==0) {
-        item->checkName();
-    } else {
-        item->checkValue();
-    }
-}
-
-
 /*!
     \fn PropertiesDlg::slotAdd()
  */
@@ -305,11 +201,11 @@ void PropertiesDlg::slotAdd()
     EditProperty_impl dlg(this);
     dlg.setDir(m_Item->isDir());
     if (dlg.exec()==QDialog::Accepted) {
-        if (protected_Property(dlg.propName())) {
+        if (PropertyListViewItem::protected_Property(dlg.propName())) {
             KMessageBox::error(this,i18n("This property may not set by users.\nRejecting it."),i18n("Protected property"));
             return;
         }
-        if (checkExisting(dlg.propName())) {
+        if (m_PropertiesListview->checkExisting(dlg.propName())) {
             KMessageBox::error(this,i18n("A property with that name exists.\nRejecting it."),i18n("Double property"));
             return;
         }
@@ -330,7 +226,7 @@ void PropertiesDlg::slotDelete()
     QListViewItem*qi = m_PropertiesListview->selectedItem();
     if (!qi) return;
     PropertyListViewItem*ki = static_cast<PropertyListViewItem*> (qi);
-    if (protected_Property(ki->currentName())) return;
+    if (PropertyListViewItem::protected_Property(ki->currentName())) return;
     if (ki->deleted()) {
         ki->unDeleteIt();
     } else {
@@ -348,18 +244,18 @@ void PropertiesDlg::slotModify()
     QListViewItem*qi = m_PropertiesListview->selectedItem();
     if (!qi) return;
     PropertyListViewItem*ki = static_cast<PropertyListViewItem*> (qi);
-    if (protected_Property(ki->currentName())) return;
+    if (PropertyListViewItem::protected_Property(ki->currentName())) return;
     /// @TODO Use a object variable to store a reference to dlg for further reuse
     EditProperty_impl dlg(this);
     dlg.setDir(m_Item->isDir());
     dlg.setPropName(ki->currentName());
     dlg.setPropValue(ki->currentValue());
     if (dlg.exec()==QDialog::Accepted) {
-        if (protected_Property(dlg.propName())) {
+        if (PropertyListViewItem::protected_Property(dlg.propName())) {
             KMessageBox::error(this,i18n("This property may not set by users.\nRejecting it."),i18n("Protected property"));
             return;
         }
-        if (checkExisting(dlg.propName(),qi)) {
+        if (m_PropertiesListview->checkExisting(dlg.propName(),qi)) {
             KMessageBox::error(this,i18n("A property with that name exists.\nRejecting it."),i18n("Double property"));
             return;
         }
@@ -370,26 +266,7 @@ void PropertiesDlg::slotModify()
     }
 }
 
-bool PropertiesDlg::checkExisting(const QString&aName,QListViewItem*it)
-{
-    if (!it) {
-        return m_PropertiesListview->findItem(aName,0)!=0;
-    }
-    QListViewItemIterator iter( m_PropertiesListview );
-    while ( iter.current() ) {
-        if ( iter.current()==it) {
-            ++iter;
-            continue;
-        }
-        if (iter.current()->text(0)==aName) {
-            return true;
-        }
-        ++iter;
-    }
-    return false;
-}
-
-void PropertiesDlg::changedItems(tPropEntries&toSet,QValueList<QString>&toDelete)
+void PropertiesDlg::changedItems(svn::PropertiesMap&toSet,QValueList<QString>&toDelete)
 {
     toSet.clear();
     toDelete.clear();
@@ -398,7 +275,8 @@ void PropertiesDlg::changedItems(tPropEntries&toSet,QValueList<QString>&toDelete
     while ( iter.current() ) {
         ki = static_cast<PropertyListViewItem*> (iter.current());
         ++iter;
-        if (protected_Property(ki->currentName())||protected_Property(ki->startName())) {
+        if (PropertyListViewItem::protected_Property(ki->currentName())||
+            PropertyListViewItem::protected_Property(ki->startName())) {
             continue;
         }
         if (ki->deleted()) {
@@ -412,11 +290,4 @@ void PropertiesDlg::changedItems(tPropEntries&toSet,QValueList<QString>&toDelete
     }
 }
 
-bool PropertiesDlg::protected_Property(const QString&what)
-{
-    if (what.compare("svn:special")!=0) return false;
-    return true;
-}
-
 #include "propertiesdlg.moc"
-
